@@ -81,7 +81,9 @@ class PostExtractor:
             'image': None,
             'image_lowquality': None,
             'images': None,
+            'images_description': None,
             'images_lowquality': None,
+            'images_lowquality_description': None,
             'video': None,
             'video_thumbnail': None,
             'video_id': None,
@@ -277,8 +279,9 @@ class PostExtractor:
         return {'user_id': self.data_ft['content_owner_id_new']}
 
     def extract_image_lq(self) -> PartialPost:
-        elems = self.element.find('div.story_body_container>div .img:not(.profpic)')
+        elems = self.element.find('div.story_body_container>div .img:not(.profpic):not([style*="static.xx.fbcdn.net"])')
         images = []
+        descriptions = []
         for elem in elems:
             if elem.attrs.get('src'):
                 images.append(elem.attrs.get('src'))
@@ -287,9 +290,10 @@ class PostExtractor:
                 if match:
                     src = utils.decode_css_url(match.groups()[0])
                     images.append(src)
+            descriptions.append(elem.attrs.get("aria-label") or elem.attrs.get("alt"))
 
         image = images[0] if images else None
-        return {"image_lowquality": image, "images_lowquality": images}
+        return {"image_lowquality": image, "images_lowquality": images, "images_lowquality_description": descriptions}
 
     def extract_link(self) -> PartialPost:
         match = self.link_regex.search(self.element.html)
@@ -359,6 +363,7 @@ class PostExtractor:
         }
 
     def extract_photo_link_HQ(self, response: Response) -> URL:
+        # Find a link that says "View Full Size"
         match = self.image_regex.search(response.text)
         if match:
             url = match.groups()[0].replace("&amp;", "&")
@@ -378,10 +383,11 @@ class PostExtractor:
         if not self.options.get("allow_extra_requests", True):
             return None
         images = []
+        descriptions = []
         photo_links = self.element.find("div.story_body_container>div a[href*='photo.php'],a[href*='/photos/']")
         total_photos_in_gallery = len(photo_links)
         if len(photo_links) == 4 and photo_links[-1].text:
-            total_photos_in_gallery = 4 + int(photo_links[-1].text.strip("+"))
+            total_photos_in_gallery = 4 + int(photo_links[-1].text.strip("+")) - 1
             logger.debug(f"{total_photos_in_gallery} total photos in gallery")
 
         # This gets up to 4 images in gallery
@@ -397,17 +403,21 @@ class PostExtractor:
             logger.debug(f"Fetching {url}")
             response = self.request(url)
             images.append(self.extract_photo_link_HQ(response))
+            elem = response.html.find(".img[data-sigil='photo-image']", first=True)
+            descriptions.append(elem.attrs.get("alt") or elem.attrs.get("aria-label"))
 
         while len(images) < total_photos_in_gallery:
-            # More photos to fetch. Follow the right arrow link of the last image we were on
-            url = response.html.find('a.touchable[data-gt=\'{"tn":"+="}\']', first=True).attrs["href"]
+            # More photos to fetch. Follow the left arrow link of the last image we were on
+            url = response.html.find('a.touchable[data-gt=\'{"tn":"+>"}\']', first=True).attrs["href"]
             if not url.startswith("http"):
                 url = utils.urljoin(FB_MOBILE_BASE_URL, url)
             logger.debug(f"Fetching {url}")
             response = self.request(url)
             images.append(self.extract_photo_link_HQ(response))
+            elem = response.html.find(".img[data-sigil='photo-image']", first=True)
+            descriptions.append(elem.attrs.get("alt") or elem.attrs.get("aria-label"))
         image = images[0] if images else None
-        return {"image": image, "images": images}
+        return {"image": image, "images": images, "images_description": descriptions}
 
     def extract_reactions(self) -> PartialPost:
         """Fetch share and reactions information with a existing post obtained by `get_posts`.
