@@ -9,6 +9,7 @@ import lxml.html
 from bs4 import BeautifulSoup
 from requests.cookies import RequestsCookieJar
 from requests_html import DEFAULT_URL, Element, PyQuery
+import json
 
 
 def find_and_search(node, selector, pattern, cast=str):
@@ -22,6 +23,7 @@ def parse_int(value: str) -> int:
 
 def convert_numeric_abbr(s):
     mapping = {'k': 1000, 'm': 1e6}
+    s = s.replace(",", "")
     if s[-1].isalpha():
         return int(float(s[:-1]) * mapping[s[-1].lower()])
     return int(s)
@@ -131,15 +133,37 @@ def parse_cookie_file(filename: str) -> RequestsCookieJar:
     jar = RequestsCookieJar()
 
     with open(filename, mode='rt') as file:
-        for line in file:
-            line = line.strip()
-            if line == "" or line.startswith('#'):
-                continue
 
-            domain, _, path, secure, expires, name, value = line.split('\t')
-            secure = secure.lower() == 'true'
-            expires = None if expires == '0' else int(expires)
+        if filename.endswith(".json"):
+            data = json.load(file)
+            if type(data) is list:
+                for c in data:
+                    expires = c.get("expirationDate") or c.get("Expires raw")
+                    if expires:
+                        expires = int(expires)
+                    if "Name raw" in c:
+                        # Cookie Quick Manager JSON format
+                        jar.set(c["Name raw"], c["Content raw"], domain=c["Host raw"], path=c["Path raw"], expires=expires)
+                    else:
+                        # EditThisCookie JSON format
+                        jar.set(c["name"], c["value"], domain=c["domain"], path=c["path"], secure=c["secure"], expires=expires)
+            elif type(data) is dict:
+                for k, v in data.items():
+                    if type(v) is dict:
+                        jar.set(k, v["value"])
+                    else:
+                        jar.set(k, v)
+        else:
+            # Netscape format
+            for line in file:
+                line = line.strip()
+                if line == "" or line.startswith('#'):
+                    continue
 
-            jar.set(name, value, domain=domain, path=path, secure=secure, expires=expires)
+                domain, _, path, secure, expires, name, value = line.split('\t')
+                secure = secure.lower() == 'true'
+                expires = None if expires == '0' else int(expires)
+
+                jar.set(name, value, domain=domain, path=path, secure=secure, expires=expires)
 
     return jar
